@@ -1,4 +1,5 @@
 import importlib
+import os
 from pathlib import Path
 
 from pyPhases.Data import DataNotFound
@@ -71,4 +72,18 @@ elif importlib.util.find_spec("tensorflow"):
         def exportDataId(self, dataId, model):
             model.save_weights(self.getPath(dataId))
 else:
-    raise Exception("No supported ModelExporter located (Supported: pytorch/tensorflow)")
+    # ability to ignore missing model exporter for testing purposes
+    if os.environ.get("PYPHASESML_IGNORE_MISSING_MODEL_EXPORTER", False):
+        raise Exception("No supported ModelExporter located (Supported: pytorch/tensorflow)")
+    else:
+        class ModelExporter(DataExporter):
+            includesStorage = True
+
+            def checkType(self, expectedType):
+                raise Exception("ModelExporter is only as stub, please install tensorflow or pytorch to use the ModelExporter")
+
+            def importData(self, dataId, options={}):
+                raise Exception("ModelExporter is only as stub, please install tensorflow or pytorch to use the ModelExporter")
+
+            def exportDataId(self, dataId, model):
+                raise Exception("ModelExporter is only as stub, please install tensorflow or pytorch to use the ModelExporter")
