@@ -35,14 +35,25 @@ class Scorer:
         self.mapping = None
         self.threshold = threshold
 
-    def prepareInput(self, inputArray):
+    def preparePrediction(self, inputArray):
         # for classification task the shape can be (recordcount?, predictions, classCount)
         isOneHotEncode = inputArray.shape[-1] == self.numClasses
         return inputArray.reshape(-1, self.numClasses) if isOneHotEncode else inputArray.reshape(-1)
+    
+    def prepareTruth(self, inputArray):
+        """flatten and squeeze the truth array"""
+        isOneHotEncode = inputArray.shape[-1] == self.numClasses
+        
+        if isOneHotEncode:
+            maskedIgnored = inputArray.sum(axis=-1) == 0
+            inputArray = np.argmax(inputArray, axis=-1)
+            inputArray[maskedIgnored] = -1
+        
+        return inputArray.reshape(-1)
 
     def score(self, truth, prediction, recordName=None, trace=True):
-        prediction = self.prepareInput(prediction)
-        truth = self.prepareInput(truth)
+        prediction = self.preparePrediction(prediction)
+        truth = self.prepareTruth(truth)
 
         truthOrg, predictionOrg = truth, prediction
         truth, prediction = self.maskedIgnoredValues(truth, prediction)
@@ -229,8 +240,8 @@ class Scorer:
     
     def getMetricScorer(self, metricName):
         def score(truth, prediction):
-            prediction = self.prepareInput(prediction)
-            truth = self.prepareInput(truth)
+            prediction = self.preparePrediction(prediction)
+            truth = self.prepareTruth(truth)
             self.results = {}
             return self.scoreMetric(metricName, truth, prediction)
         score.__name__ = metricName
